==> dasu_4.11.jar: edu/northwestern/dasu/dynamic/drools/FactScrapeProbeResult.java <==
package edu.northwestern.dasu.dynamic.drools;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import edu.northwestern.dasu.drools.FactProbeResult;
import edu.northwestern.dasu.measurement.types.ProbeType;
import edu.northwestern.dasu.util.Pair;
import edu.northwestern.dasu.util.Util;

public class FactScrapeProbeResult extends FactProbeResult{
	
	public String hash = null;
	public String type = null; //default
	public String tracker = null;
	public long timeToWait = -1; /*seconds*/ 
	public int taskId = -1;
	public boolean error = false;
	public List<String> ips = new ArrayList<String>();
	public List<Integer> ports = new ArrayList<Integer>();
	public List<Integer> udpPorts = new ArrayList<Integer>();
	public List<Boolean> isSeeds = new ArrayList<Boolean>();
	public int numSeeds = -1;
	public int numLeechers = -1;

	public long time = -1;
	
	public FactScrapeProbeResult(String hash, String type, int taskId, String trackerUrl) {
		super(ProbeType.SCRAPE);
		this.hash = hash;
		this.time = Util.currentGMTTime();
		this.type = type;
		this.taskId = taskId;
		this.tracker = trackerUrl;
		this.error = true;
	}
	
	public FactScrapeProbeResult(String hash, String type, long timeToWait, int taskId, List<String> ips, List<Integer> ports,
			List<Integer> udpPorts, List<Boolean> isSeeds, int numSeeds, int numLeechers, String trackerUrl) {
		super(ProbeType.SCRAPE);
		this.hash = hash;
		this.timeToWait = timeToWait;
		this.taskId = taskId;
		this.type = type;
		this.time = Util.currentGMTTime();
		this.ips = ips;
		this.ports = ports;
		this.udpPorts = udpPorts;
		this.isSeeds = isSeeds;
		this.numSeeds = numSeeds;
		this.numLeechers = numLeechers;
		this.tracker = trackerUrl;
		
	}

	public String getHash() {
		return hash;
	}

	public ProbeType getProbeType() {
		return probeType;
	}
	
	public String getType() {
		return type;
	}
	
	public long getTimeToWait() {
		return timeToWait;
	}

	public int getTaskId() {
		return taskId;
	}

	public boolean isError() {
		return error;
	}

	public List<String> getIps() {
		return ips;
	}

	public List<Integer> getPorts() {
		return ports;
	}

	public long getTime() {
		return time;
	}

	public void setHash(String hash) {
		this.hash = hash;
	}

	public void setProbeType(ProbeType probeType) {
		this.probeType = probeType;
	}
	
	public void getType(String type) {
		this.type = type;
	}

	public void setTimeToWait(int timeToWait) {
		this.timeToWait = timeToWait;
	}

	public void setTaskId(int taskId) {
		this.taskId = taskId;
	}

	public void setError(boolean error) {
		this.error = error;
	}

	public void setIps(List<String> ips) {
		this.ips = ips;
	}

	public void setPorts(List<Integer> ports) {
		this.ports = ports;
	}

	public void setTime(long time) {
		this.time = time;
	}

	public String getTracker() {
		return tracker;
	}

	public List<Integer> getUdpPorts() {
		return udpPorts;
	}

	public List<Boolean> getIsSeeds() {
		return isSeeds;
	}

	public void setType(String type) {
		this.type = type;
	}

	public void setTracker(String tracker) {
		this.tracker = tracker;
	}

	public void setUdpPorts(List<Integer> udpPorts) {
		this.udpPorts = udpPorts;
	}

	public void setIsSeeds(List<Boolean> isSeeds) {
		this.isSeeds = isSeeds;
	}

	public int getNumSeeds() {
		return numSeeds;
	}

	public int getNumLeechers() {
		return numLeechers;
	}

	public void setTimeToWait(long timeToWait) {
		this.timeToWait = timeToWait;
	}

	public void setNumSeeds(int numSeeds) {
		this.numSeeds = numSeeds;
	}

	public void setNumLeechers(int numLeechers) {
		this.numLeechers = numLeechers;
	}


}

==> dasu_5.31.jar: edu/northwestern/dasu/dynamic/drools/FactScrapeProbeResult.java <==
package edu.northwestern.dasu.dynamic.drools;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import edu.northwestern.dasu.drools.FactProbeResult;
import edu.northwestern.dasu.measurement.types.ProbeType;
import edu.northwestern.dasu.util.Pair;
import edu.northwestern.dasu.util.Util;

public class FactScrapeProbeResult extends FactProbeResult{
	
	private static final long serialVersionUID = 1L;
	public String hash = null;
	public String type = null; //default
	public String tracker = null;
	public long timeToWait = -1; /*seconds*/ 
	public int taskId = -1;
	public boolean error = false;
	public List<String> ips = new ArrayList<String>();
	public List<Integer> ports = new ArrayList<Integer>();
	public List<Integer> udpPorts = new ArrayList<Integer>();
	public List<Boolean> isSeeds = new ArrayList<Boolean>();
	public int numSeeds = -1;
	public int numLeechers = -1;

	public long time = -1;
	
	public FactScrapeProbeResult(String hash, String type, int taskId, String trackerUrl) {
		super(ProbeType.valueOf("SCRAPE"));
		this.hash = hash;
		this.time = Util.currentGMTTime();
		this.type = type;
		this.taskId = taskId;
		this.tracker = trackerUrl;
		this.error = true;
	}
	
	public FactScrapeProbeResult(String hash, String type, long timeToWait, int taskId, List<String> ips, List<Integer> ports,
			List<Integer> udpPorts, List<Boolean> isSeeds, int numSeeds, int numLeechers, String trackerUrl) {
		super(ProbeType.valueOf("SCRAPE"));
		this.hash = hash;
		this.timeToWait = timeToWait;
		this.taskId = taskId;
		this.type = type;
		this.time = Util.currentGMTTime();
		this.ips = ips;
		this.ports = ports;
		this.udpPorts = udpPorts;
		this.isSeeds = isSeeds;
		this.numSeeds = numSeeds;
		this.numLeechers = numLeechers;
		this.tracker = trackerUrl;
		
	}

	public String getHash() {
		return hash;
	}

	public ProbeType getProbeType() {
		return probeType;
	}
	
	public String getType() {
		return type;
	}
	
	public long getTimeToWait() {
		return timeToWait;
	}

	public int getTaskId() {
		return taskId;
	}

	public boolean isError() {
		return error;
	}

	public List<String> getIps() {
		return ips;
	}

	public List<Integer> getPorts() {
		return ports;
	}

	public long getTime() {
		return time;
	}

	public void setHash(String hash) {
		this.hash = hash;
	}

	public void setProbeType(ProbeType probeType) {
		this.probeType = probeType;
	}
	
	public void getType(String type) {
		this.type = type;
	}

	public void setTimeToWait(int timeToWait) {
		this.timeToWait = timeToWait;
	}

	public void setTaskId(int taskId) {
		this.taskId = taskId;
	}

	public void setError(boolean error) {
		this.error = error;
	}

	public void setIps(List<String> ips) {
		this.ips = ips;
	}

	public void setPorts(List<Integer> ports) {
		this.ports = ports;
	}

	public void setTime(long time) {
		this.time = time;
	}

	public String getTracker() {
		return tracker;
	}

	public List<Integer> getUdpPorts() {
		return udpPorts;
	}

	public List<Boolean> getIsSeeds() {
		return isSeeds;
	}

	public void setType(String type) {
		this.type = type;
	}

	public void setTracker(String tracker) {
		this.tracker = tracker;
	}

	public void setUdpPorts(List<Integer> udpPorts) {
		this.udpPorts = udpPorts;
	}

	public void setIsSeeds(List<Boolean> isSeeds) {
		this.isSeeds = isSeeds;
	}

	public int getNumSeeds() {
		return numSeeds;
	}

	public int getNumLeechers() {
		return numLeechers;
	}

	public void setTimeToWait(long timeToWait) {
		this.timeToWait = timeToWait;
	}

	public void setNumSeeds(int numSeeds) {
		this.numSeeds = numSeeds;
	}

	public void setNumLeechers(int numLeechers) {
		this.numLeechers = numLeechers;
	}


}
